@@ -1,5 +1,5 @@
 package Selenium::UserAgent;
-$Selenium::UserAgent::VERSION = '0.06';
+$Selenium::UserAgent::VERSION = '0.07';
 # ABSTRACT: Emulate mobile devices by setting user agents when using webdriver
 use Moo;
 use JSON;
@@ -110,14 +110,22 @@ has _chrome_options => (
     builder => sub {
         my ($self) = @_;
 
-        my $size = $self->_get_size_for('chrome');
+        my $size = $self->_get_size;
+        my $window_size = $size->{width} . ',' . $size->{height};
 
         return {
             chromeOptions => {
-                'args' => [
+                args => [
                     'user-agent=' . $self->_get_user_agent,
-                    'window-size=' . $size
-                ]
+                ],
+                mobileEmulation => {
+                    deviceMetrics => {
+                        width => $size->{width} + 0,
+                        height => $size->{height} + 0,
+                        pixelRatio => $size->{pixel_ratio}
+                    },
+                    userAgent => $self->_get_user_agent
+                }
             }
         }
     }
@@ -190,7 +198,10 @@ sub _get_size {
     my $agent = $self->agent;
     my $orientation = $self->orientation;
 
-    return $specs->{$agent}->{$orientation};
+    my $size = $specs->{$agent}->{$orientation};
+    $size->{pixel_ratio} = $specs->{$agent}->{pixel_ratio};
+
+    return $size;
 }
 
 sub _get_size_for {
@@ -229,7 +240,7 @@ Selenium::UserAgent - Emulate mobile devices by setting user agents when using w
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -253,11 +264,6 @@ on an actual mobile device, the advantage of testing this way is that
 you hardly need any additional infrastructure if you've already got a
 webdriver testing suite set up.
 
-NB: There is a bug in v2.42.2 of the Selenium standalone server for
-Retina displays, like on MacBook Pros: the scaling for Firefox will be
-doubled in both the width and height dimensions. You can either use an
-older version of the standalone server or wait for a new release.
-
 =head1 ATTRIBUTES
 
 =head2 browserName
@@ -299,7 +305,9 @@ following conversions are made to the deprecated device selections:
 
 The exact resolutions and user agents are included in the source and
 in the L<github
-repo|https://github.com/gempesaw/Selenium-UserAgent/blob/master/lib/Selenium/devices.json>.
+repo|https://github.com/gempesaw/Selenium-UserAgent/blob/master/lib/Selenium/devices.json>;
+they're vetted against the L<values that Mozilla uses for
+Firefox|https://code.cdn.mozilla.net/devices/devices.json>.
 
 Usage looks like:
 
